pub struct FieldFlags(/* private fields */);Expand description
Field access and property modifiers
Implementations
Sourceimpl FieldFlags
impl FieldFlags
Sourcepub const ACC_PUBLIC: Self
pub const ACC_PUBLIC: Self
Declared public; may be accessed from outside its package.
Sourcepub const ACC_PRIVATE: Self
pub const ACC_PRIVATE: Self
Declared private; accessible only within the defining class and other classes belonging to the same nest (JVMS 5.4.4).
Sourcepub const ACC_PROTECTED: Self
pub const ACC_PROTECTED: Self
Declared protected; may be accessed within subclasses.
Sourcepub const ACC_STATIC: Self
pub const ACC_STATIC: Self
Declared static.
Sourcepub const ACC_FINAL: Self
pub const ACC_FINAL: Self
Declared final; never directly assigned to after object construction (JLS 17.5).
Sourcepub const ACC_VOLATILE: Self
pub const ACC_VOLATILE: Self
Declared volatile; cannot be cached.
Sourcepub const ACC_TRANSIENT: Self
pub const ACC_TRANSIENT: Self
Declared transient; not written or read by a persistent object manager.
Sourcepub const ACC_SYNTHETIC: Self
pub const ACC_SYNTHETIC: Self
Declared synthetic; not present in the source code.
Sourceimpl FieldFlags
impl FieldFlags
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl FieldFlags
impl FieldFlags
Sourcepub const fn iter(&self) -> Iter<FieldFlags>
pub const fn iter(&self) -> Iter<FieldFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<FieldFlags>
pub const fn iter_names(&self) -> IterNames<FieldFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.